@@ -3,7 +3,9 @@ import itertools
 from BTrees.OOBTree import OOBTree
 from ..types import SmallDict
 from sheraf.databases import Database
-from sheraf.exceptions import NotConnectedException, UniqueIndexException
+from sheraf.exceptions import NoDatabaseConnectionException
+from sheraf.exceptions import NotConnectedException
+from sheraf.exceptions import UniqueIndexException
 
 
 class IndexManager:
@@ -187,6 +189,11 @@ class SimpleIndexManager(IndexManager):
             return reversed(list(self.table().iterkeys()))
         return self.table().iterkeys()
 
+    def itervalues(self, reverse=False):
+        if reverse:
+            return reversed(list(self.table().itervalues()))
+        return self.table().itervalues()
+
     def count(self):
         try:
             return len(self.persistent[self.details.key])
@@ -212,7 +219,10 @@ class MultipleDatabaseIndexManager(IndexManager):
         return Database.current_connection(database_name).root()
 
     def root(self, database_name=None, setdefault=True):
-        root = self.database_root(database_name)
+        try:
+            root = self.database_root(database_name)
+        except KeyError as exc:
+            raise NoDatabaseConnectionException(database_name) from exc
         try:
             return root[self.table_name]
         except KeyError:
@@ -312,5 +322,15 @@ class MultipleDatabaseIndexManager(IndexManager):
             table.iterkeys() for table in self.tables()
         )
 
+    def itervalues(self, reverse=False):
+        if reverse:
+            return itertools.chain.from_iterable(
+                reversed(list(table.itervalues())) for table in self.tables()
+            )
+
+        return itertools.chain.from_iterable(
+            table.itervalues() for table in self.tables()
+        )
+
     def count(self):
         return sum(len(table) for table in self.tables())
